local name = "Respawn Timers"
local L = AceLibrary("AceLocale-2.0"):new("BigWigs"..name)

L:RegisterTranslations("enUS", function() return {
	["respawntimers"] = true,
	["Respawn Timers"] = true,
	["Respawn timer bars and warnings for trash mobs."] = true,
	["bars"] = true,
	["Bars"] = true,
	["Toggles showing bars for respawn times."] = true,
	["messages"] = true,
	["Messages"] = true,
	["Toggles showing messages for respawn times."] = true,

	["%s %d respawns in %d sec"] = true,
	["%s %d respawned!"] = true,
	["Respawn: %s %d"] = true,

	-- Molten Core Triggers
	["Ancient Core Hound"] = true,
	["Lava Annihilator"] = true,
	["Lava Surger"] = true,
	["Firelord"] = true,
	["Firewalker"] = true, -- Lava Pack
	["%s collapses and begins to smolder."] = true, -- Hound Pack, emote.
	-- Molten Core Messages
	["Corehound"] = true,
	["Annihilator"] = true,
	["Surger"] = true,
	-- Firelord == Firelord.
	["Lavapack"] = true,
	["Houndpack"] = true,

	-- AQ Triggers
	["Obsidian Eradicator"] = true,
	["Anubisath Sentinel"] = true,
	-- AQ Messages
	["Eradicator"] = true,
	["Sentinel"] = true,

	-- BWL Triggers
	["Death Talon Hatcher"] = true,
	["Blackwing Taskmaster"] = true,
	-- BWL Messages
	["Death Talon"] = true,
	["Taskmaster"] = true,

} end )

local deathTable = {
	-- MC
	[L["Ancient Core Hound"]] = {1080, L["Corehound"], nil},
	[L["Lava Annihilator"]]   = {7200, L["Annihilator"], nil},
	[L["Lava Surger"]]        = {1620, L["Surger"], nil},
	[L["Firelord"]]           = {7200, L["Firelord"], nil},
	[L["Firewalker"]]         = {7200, L["Lavapack"], nil},
	-- AQ
	[L["Obsidian Eradicator"]] = {1800, L["Eradicator"], nil},
	[L["Anubisath Sentinel"]]  = {1800, L["Sentinel"], nil},
	-- BWL
	[L["Death Talon Hatcher"]]  = {720, L["Death Talon"], nil},
	[L["Blackwing Taskmaster"]] = {720, L["Taskmaster"], nil},
}
local emoteTable = {
	-- MC
	[L["%s collapses and begins to smolder."]] = {3600, L["Houndpack"], nil},
}
local packNumber = nil
local deathThrottle = nil

BigWigsRespawnTimers = BigWigs:NewModule(name)
BigWigsRespawnTimers.defaultDB = {
	bars = true,
	messages = true,
}

BigWigsRespawnTimers.consoleCmd = L["respawntimers"]
BigWigsRespawnTimers.consoleOptions = {
	type = "group",
	name = L["Respawn Timers"],
	desc = L["Respawn timer bars and warnings for trash mobs."],
	args   = {
		[L["bars"]] = {
			type = "toggle",
			name = L["Bars"],
			desc = L["Toggles showing bars for respawn times."],
			get = function() return BigWigsRespawnTimers.db.profile.bars end,
			set = function(v) BigWigsRespawnTimers.db.profile.bars = v end,
		},
		[L["messages"]] = {
			type = "toggle",
			name = L["Messages"],
			desc = L["Toggles showing messages for respawn times."],
			get = function() return BigWigsRespawnTimers.db.profile.messages end,
			set = function(v) BigWigsRespawnTimers.db.profile.messages = v end,
		},
	}
}
BigWigsRespawnTimers.revision = tonumber(string.sub("$Revision: 13068 $", 12, -3))

function BigWigsRespawnTimers:OnEnable()
	packNumber = {}
	deathThrottle = {}
	self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH")
	self:RegisterEvent("CHAT_MSG_MONSTER_EMOTE")
end

function BigWigsRespawnTimers:CHAT_MSG_COMBAT_HOSTILE_DEATH(msg)
	for key, table in pairs(deathTable) do
		if msg == string.format(UNITDIESOTHER, key) then
			self:StartRespawnTimer(table[2], table[1], table[3])
			break
		end
	end
end

function BigWigsRespawnTimers:CHAT_MSG_MONSTER_EMOTE(msg)
	for key, table in pairs(emoteTable) do
		if msg == key then
			self:StartRespawnTimer(table[2], table[1], table[3])
		end
	end
end

function BigWigsRespawnTimers:StartRespawnTimer(message, timer, icon, throttle)
	if not packNumber[message] then packNumber[message] = 0 end
	timer = tonumber(timer)
	if timer == nil then return end

	-- Throttle deaths
	if deathThrottle[message] and (deathThrottle[message] + 60) > GetTime() then return end
	deathThrottle[message] = GetTime()

	local nextPack = packNumber[message] + 1
	packNumber[message] = nextPack

	if self.db.profile.messages then
		self:ScheduleEvent("bwrt"..nextPack.."10secwarn", "BigWigs_Message", timer - 10, string.format(L["%s %d respawns in %d sec"], message, nextPack, timer - 10), "Yellow")
		self:ScheduleEvent("bwrt"..nextPack.."respawned", "BigWigs_Message", timer, string.format(L["%s %d respawned!"], message, nextPack), "Orange")
	end
	if self.db.profile.bars then
		if not icon then icon = "Interface\\Icons\\INV_Misc_Head_Dragon_01" end
		self:TriggerEvent("BigWigs_StartBar", self, string.format(L["Respawn: %s %d"], message, nextPack), timer, icon)
	end
end

